@@ -1088,3 +1088,15 @@ ddc_ensure_displays_detected() {
    }
 }
 
+void ddc_free_all_displays() {
+   if(all_displays == NULL) {
+      return;
+   }
+
+   g_ptr_array_free(all_displays, true);
+   all_displays = NULL;
+
+   //reset static var
+   dispno_max = 0;
+}
+
