@@ -958,6 +958,13 @@ int i2c_detect_buses() {
    return result;
 }
 
+int i2c_free_buses(){
+   if(i2c_buses != NULL){
+      g_ptr_array_free(i2c_buses, true);
+      i2c_buses = NULL;
+   }
+   return 0;
+}
 
 I2C_Bus_Info * detect_single_bus(int busno) {
    bool debug = false;
