@@ -1173,6 +1173,14 @@ ddca_free_display_info_list(DDCA_Display_Info_List * dlist) {
    }
 }
 
+int ddca_free_all_displays(void){
+   i2c_free_buses();
+   usb_monitor_list_free();
+   ddc_free_all_displays();
+   clean_distinct_displays();
+   return 0;
+}
+
 
 void
 ddca_report_display_info(
