@@ -409,7 +409,13 @@ GPtrArray * get_usb_monitor_list() {
    return usb_monitors;
 }
 
-
+int usb_monitor_list_free(){
+   if(usb_monitors != NULL){
+      g_ptr_array_free(usb_monitors, true);
+      usb_monitors = NULL;
+   }
+   return 0;
+}
 
 //
 // Functions to find Usb_Monitor_Info for a display
